@@ -30,7 +30,7 @@ describe 'ceph::repo' do
 
       it { should contain_apt__source('ceph').with(
         :location => 'http://download.ceph.com/debian-nautilus/',
-        :release  => facts[:lsbdistcodename],
+        :release  => facts[:os]['distro']['codename'],
       )}
     end
 
@@ -43,7 +43,7 @@ describe 'ceph::repo' do
 
       it { should contain_apt__source('ceph').with(
         :location => 'http://myserver.com/debian-nautilus/',
-        :release  => facts[:lsbdistcodename],
+        :release  => facts[:os]['distro']['codename'],
       )}
     end
 
@@ -61,13 +61,13 @@ describe 'ceph::repo' do
 
       it { should contain_apt__source('ceph').with(
         :location => 'http://download.ceph.com/debian-nautilus/',
-        :release  => facts[:lsbdistcodename],
+        :release  => facts[:os]['distro']['codename'],
       )}
 
       it { should contain_apt__source('ceph-fastcgi').with(
         :ensure   => 'present',
-        :location => "http://gitbuilder.ceph.com/libapache-mod-fastcgi-deb-#{facts[:lsbdistcodename]}-x86_64-basic/ref/master",
-        :release  => facts[:lsbdistcodename],
+        :location => "http://gitbuilder.ceph.com/libapache-mod-fastcgi-deb-#{facts[:os]['distro']['codename']}-x86_64-basic/ref/master",
+        :release  => facts[:os]['distro']['codename'],
         :require  => 'Apt::Key[ceph-gitbuilder]'
       )}
     end
@@ -83,13 +83,13 @@ describe 'ceph::repo' do
       it { should contain_apt__source('ceph').with(
         :ensure   => 'absent',
         :location => 'http://download.ceph.com/debian-nautilus/',
-        :release  => facts[:lsbdistcodename],
+        :release  => facts[:os]['distro']['codename'],
       )}
 
       it { should contain_apt__source('ceph-fastcgi').with(
         :ensure   => 'absent',
-        :location => "http://gitbuilder.ceph.com/libapache-mod-fastcgi-deb-#{facts[:lsbdistcodename]}-x86_64-basic/ref/master",
-        :release  => facts[:lsbdistcodename],
+        :location => "http://gitbuilder.ceph.com/libapache-mod-fastcgi-deb-#{facts[:os]['distro']['codename']}-x86_64-basic/ref/master",
+        :release  => facts[:os]['distro']['codename'],
         :require  => 'Apt::Key[ceph-gitbuilder]'
       )}
     end
@@ -97,23 +97,23 @@ describe 'ceph::repo' do
 
   shared_examples 'ceph::repo on RedHat' do
     context 'with default params' do
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled    => '1',
-        :descr      => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name       => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure     => 'present',
+        :descr      => "External EPEL #{facts[:os]['release']['major']}",
+        :name       => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl    => 'absent',
         :gpgcheck   => '1',
-        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority   => '20',
         :exclude    => 'python-ceph-compat python-rbd python-rados python-cephfs',
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph nautilus',
         :name       => 'ext-ceph-nautilus',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -121,10 +121,10 @@ describe 'ceph::repo' do
      )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph noarch',
         :name       => 'ext-ceph-nautilus-noarch',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -139,23 +139,23 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled    => '1',
-        :descr      => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name       => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure     => 'present',
+        :descr      => "External EPEL #{facts[:os]['release']['major']}",
+        :name       => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl    => 'absent',
         :gpgcheck   => '1',
-        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority   => '20',
         :exclude    => 'python-ceph-compat python-rbd python-rados python-cephfs',
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph firefly',
         :name       => 'ext-ceph-firefly',
-        :baseurl    => "http://download.ceph.com/rpm-firefly/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl    => "http://download.ceph.com/rpm-firefly/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -163,10 +163,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph noarch',
         :name       => 'ext-ceph-firefly-noarch',
-        :baseurl    => "http://download.ceph.com/rpm-firefly/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl    => "http://download.ceph.com/rpm-firefly/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -181,7 +181,7 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should_not contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}") }
+      it { should_not contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}") }
     end
 
     context 'when using a proxy for yum repositories' do
@@ -193,14 +193,14 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled        => '1',
-        :descr          => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name           => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure         => 'present',
+        :descr          => "External EPEL #{facts[:os]['release']['major']}",
+        :name           => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl        => 'absent',
         :gpgcheck       => '1',
-        :gpgkey         => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist     => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey         => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist     => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority       => '20',
         :exclude        => 'python-ceph-compat python-rbd python-rados python-cephfs',
         :proxy          => 'http://someproxy.com:8080/',
@@ -209,10 +209,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled        => '1',
+        :ensure         => 'present',
         :descr          => 'External Ceph nautilus',
         :name           => 'ext-ceph-nautilus',
-        :baseurl        => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl        => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck       => '1',
         :gpgkey         => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist     => 'absent',
@@ -223,10 +223,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled        => '1',
+        :ensure         => 'present',
         :descr          => 'External Ceph noarch',
         :name           => 'ext-ceph-nautilus-noarch',
-        :baseurl        => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl        => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck       => '1',
         :gpgkey         => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist     => 'absent',
@@ -245,23 +245,23 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled    => '0',
-        :descr      => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name       => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure     => 'absent',
+        :descr      => "External EPEL #{facts[:os]['release']['major']}",
+        :name       => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl    => 'absent',
         :gpgcheck   => '1',
-        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority   => '20',
         :exclude    => 'python-ceph-compat python-rbd python-rados python-cephfs',
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled    => '0',
+        :ensure     => 'absent',
         :descr      => 'External Ceph nautilus',
         :name       => 'ext-ceph-nautilus',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -269,10 +269,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled    => '0',
+        :ensure     => 'absent',
         :descr      => 'External Ceph noarch',
         :name       => 'ext-ceph-nautilus-noarch',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -280,10 +280,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-fastcgi').with(
-        :enabled    => '0',
+        :ensure     => 'absent',
         :descr      => 'FastCGI basearch packages for Ceph',
         :name       => 'ext-ceph-fastcgi',
-        :baseurl    => "http://gitbuilder.ceph.com/mod_fastcgi-rpm-rhel#{facts[:operatingsystemmajrelease]}-x86_64-basic/ref/master",
+        :baseurl    => "http://gitbuilder.ceph.com/mod_fastcgi-rpm-rhel#{facts[:os]['release']['major']}-x86_64-basic/ref/master",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/autobuild.asc',
         :mirrorlist => 'absent',
@@ -298,23 +298,23 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled    => '1',
-        :descr      => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name       => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure     => 'present',
+        :descr      => "External EPEL #{facts[:os]['release']['major']}",
+        :name       => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl    => 'absent',
         :gpgcheck   => '1',
-        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority   => '20',
         :exclude    => 'python-ceph-compat python-rbd python-rados python-cephfs',
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph nautilus',
         :name       => 'ext-ceph-nautilus',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -322,10 +322,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph noarch',
         :name       => 'ext-ceph-nautilus-noarch',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -333,10 +333,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-fastcgi').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'FastCGI basearch packages for Ceph',
         :name       => 'ext-ceph-fastcgi',
-        :baseurl    => "http://gitbuilder.ceph.com/mod_fastcgi-rpm-rhel#{facts[:operatingsystemmajrelease]}-x86_64-basic/ref/master",
+        :baseurl    => "http://gitbuilder.ceph.com/mod_fastcgi-rpm-rhel#{facts[:os]['release']['major']}-x86_64-basic/ref/master",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/autobuild.asc',
         :mirrorlist => 'absent',
@@ -347,23 +347,23 @@ describe 'ceph::repo' do
 
   shared_examples 'ceph::repo on CentOS' do
     context 'with default params' do
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled    => '1',
-        :descr      => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name       => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure     => 'present',
+        :descr      => "External EPEL #{facts[:os]['release']['major']}",
+        :name       => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl    => 'absent',
         :gpgcheck   => '1',
-        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority   => '20',
         :exclude    => 'python-ceph-compat python-rbd python-rados python-cephfs',
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph nautilus',
         :name       => 'ext-ceph-nautilus',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -371,10 +371,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph noarch',
         :name       => 'ext-ceph-nautilus-noarch',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -389,23 +389,23 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled    => '1',
-        :descr      => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name       => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure     => 'present',
+        :descr      => "External EPEL #{facts[:os]['release']['major']}",
+        :name       => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl    => 'absent',
         :gpgcheck   => '1',
-        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority   => '20',
         :exclude    => 'python-ceph-compat python-rbd python-rados python-cephfs',
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph firefly',
         :name       => 'ext-ceph-firefly',
-        :baseurl    => "http://download.ceph.com/rpm-firefly/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl    => "http://download.ceph.com/rpm-firefly/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -413,10 +413,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph noarch',
         :name       => 'ext-ceph-firefly-noarch',
-        :baseurl    => "http://download.ceph.com/rpm-firefly/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl    => "http://download.ceph.com/rpm-firefly/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -431,49 +431,12 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should_not contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}") }
+      it { should_not contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}") }
       it { should_not contain_yumrepo('ext-ceph') }
       it { should_not contain_yumrepo('ext-ceph-noarch') }
-      it { should contain_yumrepo('ceph-luminous-sig').with_ensure('absent') }
 
       it { should contain_yumrepo('ceph-storage-sig').with(
-        :baseurl => "http://mirror.centos.org/centos/#{facts[:operatingsystemmajrelease]}/storage/x86_64/ceph-nautilus/",
-      )}
-    end
-
-    context 'when using CentOS SIG repository and CentOS Stream 8' do
-      before do
-        facts.merge!( :operatingsystemmajrelease => "8" )
-      end
-
-      let :params do
-        {
-          :enable_sig => true,
-          :stream     => true,
-        }
-      end
-
-      it { should contain_yumrepo('ceph-luminous-sig').with_ensure('absent') }
-
-      it { should contain_yumrepo('ceph-storage-sig').with(
-        :baseurl => 'http://mirror.centos.org/centos/8-stream/storage/x86_64/ceph-nautilus/',
-      )}
-    end
-
-    context 'when using CentOS SIG repository and CentOS Stream 9' do
-      before do
-        facts.merge!( :operatingsystemmajrelease => "9" )
-      end
-
-      let :params do
-        {
-          :enable_sig => true,
-          :stream     => true,
-        }
-      end
-
-      it { should contain_yumrepo('ceph-storage-sig').with(
-        :baseurl => 'http://mirror.stream.centos.org/SIGs/9-stream/storage/x86_64/ceph-nautilus/',
+        :baseurl => "http://mirror.centos.org/centos/#{facts[:os]['release']['major']}/storage/x86_64/ceph-nautilus/",
       )}
     end
 
@@ -485,10 +448,9 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should_not contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}") }
+      it { should_not contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}") }
       it { should_not contain_yumrepo('ext-ceph') }
       it { should_not contain_yumrepo('ext-ceph-noarch') }
-      it { should contain_yumrepo('ceph-luminous-sig').with_ensure('absent') }
 
       it { should contain_yumrepo('ceph-storage-sig').with(
         :baseurl => 'https://mymirror/luminous/',
@@ -503,23 +465,23 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled    => '0',
-        :descr      => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name       => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure     => 'absent',
+        :descr      => "External EPEL #{facts[:os]['release']['major']}",
+        :name       => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl    => 'absent',
         :gpgcheck   => '1',
-        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority   => '20',
         :exclude    => 'python-ceph-compat python-rbd python-rados python-cephfs',
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled    => '0',
+        :ensure     => 'absent',
         :descr      => 'External Ceph nautilus',
         :name       => 'ext-ceph-nautilus',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -527,10 +489,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled    => '0',
+        :ensure     => 'absent',
         :descr      => 'External Ceph noarch',
         :name       => 'ext-ceph-nautilus-noarch',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -538,10 +500,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-fastcgi').with(
-        :enabled    => '0',
+        :ensure     => 'absent',
         :descr      => 'FastCGI basearch packages for Ceph',
         :name       => 'ext-ceph-fastcgi',
-        :baseurl    => "http://gitbuilder.ceph.com/mod_fastcgi-rpm-rhel#{facts[:operatingsystemmajrelease]}-x86_64-basic/ref/master",
+        :baseurl    => "http://gitbuilder.ceph.com/mod_fastcgi-rpm-rhel#{facts[:os]['release']['major']}-x86_64-basic/ref/master",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/autobuild.asc',
         :mirrorlist => 'absent',
@@ -556,23 +518,23 @@ describe 'ceph::repo' do
         }
       end
 
-      it { should contain_yumrepo("ext-epel-#{facts[:operatingsystemmajrelease]}").with(
-        :enabled    => '1',
-        :descr      => "External EPEL #{facts[:operatingsystemmajrelease]}",
-        :name       => "ext-epel-#{facts[:operatingsystemmajrelease]}",
+      it { should contain_yumrepo("ext-epel-#{facts[:os]['release']['major']}").with(
+        :ensure     => 'present',
+        :descr      => "External EPEL #{facts[:os]['release']['major']}",
+        :name       => "ext-epel-#{facts[:os]['release']['major']}",
         :baseurl    => 'absent',
         :gpgcheck   => '1',
-        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:operatingsystemmajrelease]}",
-        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:operatingsystemmajrelease]}&arch=$basearch",
+        :gpgkey     => "https://dl.fedoraproject.org/pub/epel/RPM-GPG-KEY-EPEL-#{facts[:os]['release']['major']}",
+        :mirrorlist => "http://mirrors.fedoraproject.org/metalink?repo=epel-#{facts[:os]['release']['major']}&arch=$basearch",
         :priority   => '20',
         :exclude    => 'python-ceph-compat python-rbd python-rados python-cephfs',
       )}
 
       it { should contain_yumrepo('ext-ceph').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph nautilus',
         :name       => 'ext-ceph-nautilus',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/$basearch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/$basearch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -580,10 +542,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-noarch').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'External Ceph noarch',
         :name       => 'ext-ceph-nautilus-noarch',
-        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:operatingsystemmajrelease]}/noarch",
+        :baseurl    => "http://download.ceph.com/rpm-nautilus/el#{facts[:os]['release']['major']}/noarch",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/release.asc',
         :mirrorlist => 'absent',
@@ -591,10 +553,10 @@ describe 'ceph::repo' do
       )}
 
       it { should contain_yumrepo('ext-ceph-fastcgi').with(
-        :enabled    => '1',
+        :ensure     => 'present',
         :descr      => 'FastCGI basearch packages for Ceph',
         :name       => 'ext-ceph-fastcgi',
-        :baseurl    => "http://gitbuilder.ceph.com/mod_fastcgi-rpm-rhel#{facts[:operatingsystemmajrelease]}-x86_64-basic/ref/master",
+        :baseurl    => "http://gitbuilder.ceph.com/mod_fastcgi-rpm-rhel#{facts[:os]['release']['major']}-x86_64-basic/ref/master",
         :gpgcheck   => '1',
         :gpgkey     => 'https://download.ceph.com/keys/autobuild.asc',
         :mirrorlist => 'absent',
@@ -603,6 +565,40 @@ describe 'ceph::repo' do
     end
   end
 
+  shared_examples 'ceph::repo on CentOS Stream 7' do
+    # No specific test cases
+  end
+
+  shared_examples 'ceph::repo on CentOS Stream 8' do
+    context 'when using CentOS SIG repository and CentOS Stream 8' do
+      let :params do
+        {
+          :enable_sig => true,
+          :stream     => true,
+        }
+      end
+
+      it { should contain_yumrepo('ceph-storage-sig').with(
+        :baseurl => 'http://mirror.centos.org/centos/8-stream/storage/x86_64/ceph-nautilus/',
+      )}
+    end
+  end
+
+  shared_examples 'ceph::repo on CentOS Stream 9' do
+    context 'when using CentOS SIG repository and CentOS Stream 9' do
+      let :params do
+        {
+          :enable_sig => true,
+          :stream     => true,
+        }
+      end
+
+      it { should contain_yumrepo('ceph-storage-sig').with(
+        :baseurl => 'http://mirror.stream.centos.org/SIGs/9-stream/storage/x86_64/ceph-nautilus/',
+      )}
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -611,10 +607,11 @@ describe 'ceph::repo' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      it_behaves_like "ceph::repo on #{facts[:osfamily]}"
+      it_behaves_like "ceph::repo on #{facts[:os]['family']}"
 
-      if facts[:operatingsystem] == 'CentOS'
+      if facts[:os]['name'] == 'CentOS'
         it_behaves_like 'ceph::repo on CentOS'
+        it_behaves_like "ceph::repo on CentOS Stream #{facts[:os]['release']['major']}"
       end
     end
   end
