@@ -36,10 +36,12 @@ describe 'ceph::fs' do
     end
   end
 
-  on_supported_os.each do |os,facts|
+  on_supported_os({
+    :supported_os => OSDefaults.get_supported_os
+  }).each do |os,facts|
     context "on #{os}" do
       let (:facts) do
-        facts.merge!(OSDefaults.get_facts({:hostname => 'myhostname'}))
+        facts.merge!(OSDefaults.get_facts())
       end
 
       it_behaves_like 'ceph fs'
